@@ -124,6 +124,19 @@ class History:
 
     @utils.ignore_errors
     def flush(self):
+        # Supress db write if record don't changed.
+        if len(self.buffer) == 1:
+            ret = self.storage.conn.execute('''
+                SELECT value, info FROM {0} as T
+                    WHERE T.id = (SELECT max(id) FROM {0})
+                '''.format(self.table_name))
+            rec = ret.fetchone()
+            if rec:
+                if self.buffer[0][0] == rec[0]:
+                    if self.buffer[0][1] == json.loads(rec[1]):
+                        del self.buffer[:]
+                        return
+
         for value, info in self.buffer[::-1]:
             ret = self.storage.conn.execute('''
                 DELETE FROM {} WHERE value = ?'''.format(self.table_name),
