@@ -289,6 +289,8 @@ class TextEditorWindow(Window):
                     self.add_str(' ' * (lineno_width - 1), lineno_color)
 
                 self.add_str(' ', defaultcolor)
+            # increment line no
+            lineno += 1
 
             # move cursor to top of row
             self._cwnd.move(n, row.wrapindent + lineno_width)
@@ -338,14 +340,16 @@ class TextEditorWindow(Window):
 
     CURSOR_TO_MIDDLE_ON_SCROLL = True
 
-    def locate_cursor(self, pos, top=None, middle=None, bottom=None):
+    def locate_cursor(self, pos, top=None, middle=None, bottom=None,
+                      align_always=False):
 
         if top is middle is bottom is None:
             middle = self.CURSOR_TO_MIDDLE_ON_SCROLL
             bottom = not self.CURSOR_TO_MIDDLE_ON_SCROLL
 
         self.screen.apply_updates()
-        self.screen.locate(pos, top=top, middle=middle, bottom=bottom)
+        self.screen.locate(pos, top=top, middle=middle, bottom=bottom,
+                           align_always=align_always)
 
         idx, x = self.screen.getrowcol(pos)
         y = idx - self.screen.portfrom
