@@ -94,7 +94,7 @@ class DefaultMode(modebase.ModeBase):
     def on_keypressed(self, wnd, event, s, commands, candidate):
         if not commands and not candidate:
             if not s or s[0] < ' ':
-                kaa.app.messagebar.set_message(kaa.app.SHOW_MENU_MESSAGE)
+                kaa.app.messagebar.set_message(kaa.app.DEFAULT_MENU_MESSAGE)
 
         return super().on_keypressed(wnd, event, s, commands, candidate)
 
