@@ -15,6 +15,7 @@ from kaa.ui.inputline import inputlinemode
 pythonconsole_keys = {
     ('\r'): 'python.exec',
     (alt, '\r'): 'python.script-history',
+    (alt, '\n'): 'python.script-history',
 }
 
 PythonConsoleThemes = {
@@ -62,9 +63,9 @@ class PythonConsoleMode(pythonmode.PythonMode):
 
     def on_set_document(self, document):
         super().on_set_document(document)
-        self.document.marks['current_script'] = (0, 0)
         self.interp = KaaInterpreter()
 
+        self.document.append('Python %s\n' % sys.version, self.get_styleid('ps'))
         self.document.append('>>>', self.get_styleid('ps'))
         self.document.append('\n', self.get_styleid('default'))
         p = self.document.endpos()
@@ -87,6 +88,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
         f, t = self.document.marks['current_script']
         if not (f <= pos <= t):
             wnd.cursor.setpos(t)
+            wnd.screen.selection.clear()
 
         super().put_string(wnd, s)
 
@@ -159,9 +161,12 @@ class PythonConsoleMode(pythonmode.PythonMode):
                 self.document.marks['current_script'] = (p, p)
                 wnd.cursor.setpos(p)
             else:
-                doc = PythonInputlineMode.build(wnd, s + '\n')
-                kaa.app.show_dialog(doc)
-                kaa.app.messagebar.set_message('')
+                self._show_inputline(wnd, s+'\n')
+
+    def _show_inputline(self, wnd, s):
+        doc = PythonInputlineMode.build(wnd, s)
+        kaa.app.show_dialog(doc)
+        kaa.app.messagebar.set_message('')
 
     def exec_str(self, wnd, s):
         s = s.rstrip() + '\n'
@@ -170,6 +175,17 @@ class PythonConsoleMode(pythonmode.PythonMode):
                               style=self.get_styleid('default'))
         self.exec_script(wnd)
 
+    def _put_script(self, wnd, text):
+        self.put_string(wnd, text)
+        wnd.screen.selection.clear()
+        hist = kaa.app.config.hist('pyconsole_script', self.MAX_HISTORY)
+        hist.add(text)
+
+        f, t = self.document.marks['current_script']
+        s = wnd.document.gettext(f, t)
+        if '\n' in s:
+            self._show_inputline(wnd, s)
+
     MAX_HISTORY = 100
 
     @command('python.script-history')
@@ -183,13 +199,18 @@ class PythonConsoleMode(pythonmode.PythonMode):
 
         def callback(text):
             if text:
-                wnd.document.mode.put_string(wnd, text)
-                wnd.screen.selection.clear()
-                hist.add(text)
+                self._put_script(wnd, text)
 
         from kaa.ui.texthist import texthistmode
         texthistmode.show_history(callback, scripts)
 
+    @command('edit.paste')
+    def paste(self, wnd):
+        s = kaa.app.clipboard.get()
+        if s:
+            self._put_script(wnd, s)
+
+
 inputline_keys = {
     (alt, '\r'): ('inputline'),
     (alt, '\n'): ('inputline'),
