@@ -14,63 +14,6 @@ SearchThemes = {
 }
 
 
-class SearchCommands(editorcommand.EditCommands):
-    # todo: move commands to mode class
-
-    @command('searchdlg.search.next')
-    @norec
-    @norerun
-    def search_next(self, wnd):
-        mode = wnd.document.mode
-        mode.search_next(wnd)
-
-    @command('searchdlg.search.prev')
-    @norec
-    @norerun
-    def search_prev(self, wnd):
-        mode = wnd.document.mode
-        mode.search_prev(wnd)
-
-    def _show_histdlg(self, wnd, title, candidates, callback):
-        filterlist.show_listdlg(title, candidates, callback)
-
-    @command('searchdlg.history')
-    @norec
-    @norerun
-    def search_history(self, wnd):
-        def callback(result):
-            if result:
-                f, t = wnd.document.marks['searchtext']
-                wnd.document.replace(f, t, result)
-                wnd.cursor.setpos(f)
-
-        self._show_histdlg(wnd, 'Recent searches',
-                           [s for s,
-                               info in kaa.app.config.hist(
-                                   'search_text').get()],
-                           callback)
-
-    @command('searchdlg.toggle.ignorecase')
-    @norec
-    @norerun
-    def toggle_ignorecase(self, wnd):
-        mode = wnd.document.mode
-        mode.toggle_option_ignorecase()
-
-    @command('searchdlg.toggle.wordsearch')
-    @norec
-    @norerun
-    def toggle_wordsearch(self, wnd):
-        mode = wnd.document.mode
-        mode.toggle_option_wordsearch()
-
-    @command('searchdlg.toggle.regex')
-    @norec
-    @norerun
-    def toggle_regex(self, wnd):
-        mode = wnd.document.mode
-        mode.toggle_option_regex()
-
 searchdlg_keys = {
     '\r': ('searchdlg.search.next'),
     '\n': ('searchdlg.search.next'),
@@ -119,21 +62,6 @@ class SearchDlgMode(dialogmode.DialogMode):
         self.register_keys(self.keybind, self.KEY_BINDS)
         self.keybind.add_keybind(searchdlg_keys)
 
-    def init_commands(self):
-        super().init_commands()
-
-        self.cursor_commands = editorcommand.CursorCommands()
-        self.register_command(self.cursor_commands)
-
-        self.edit_commands = editorcommand.EditCommands()
-        self.register_command(self.edit_commands)
-
-        self.screen_commands = editorcommand.ScreenCommands()
-        self.register_command(self.screen_commands)
-
-        self._searchcommands = SearchCommands()
-        self.register_command(self._searchcommands)
-
     def init_themes(self):
         super().init_themes()
         self.themes.append(SearchThemes)
@@ -159,31 +87,31 @@ class SearchDlgMode(dialogmode.DialogMode):
 
     def _build_buttons(self, f):
         # buttons
-        f.append_text('checkbox', '[&Next]',
+        f.append_text('right-button', '[&Next]',
                       shortcut_style='button.shortcut',
                       on_shortcut=self.search_next)
 
-        f.append_text('checkbox', '[&Prev]',
+        f.append_text('right-button', '[&Prev]',
                       shortcut_style='button.shortcut',
                       on_shortcut=self.search_prev)
 
     def _build_options(self, f):
-        f.append_text('checkbox', '[&Ignore case]',
+        f.append_text('right-button', '[&Ignore case]',
                       mark_pair='ignore-case',
                       on_shortcut=self.toggle_option_ignorecase,
-                      shortcut_style='checkbox.shortcut',
+                      shortcut_style='right-button.shortcut',
                       shortcut_mark='shortcut-i')
 
-        f.append_text('checkbox', '[&Word]',
+        f.append_text('right-button', '[&Word]',
                       mark_pair='word',
                       on_shortcut=self.toggle_option_word,
-                      shortcut_style='checkbox.shortcut',
+                      shortcut_style='right-button.shortcut',
                       shortcut_mark='shortcut-w')
 
-        f.append_text('checkbox', '[&Regex]',
+        f.append_text('right-button', '[&Regex]',
                       mark_pair='regex',
                       on_shortcut=self.toggle_option_regex,
-                      shortcut_style='checkbox.shortcut',
+                      shortcut_style='right-button.shortcut',
                       shortcut_mark='shortcut-r')
 
     def build_document(self):
@@ -216,29 +144,57 @@ class SearchDlgMode(dialogmode.DialogMode):
 
     def update_option_style(self):
         style = self._get_optionstylename(self.option.ignorecase)
-        self._set_option_style('ignore-case', 'checkbox' + style, 'shortcut-i',
-                               'checkbox.shortcut' + style)
+        self._set_option_style(
+            'ignore-case', 'right-button' + style, 'shortcut-i',
+            'right-button.shortcut' + style)
 
         style = self._get_optionstylename(self.option.word)
-        self._set_option_style('word', 'checkbox' + style, 'shortcut-w',
-                               'checkbox.shortcut' + style)
+        self._set_option_style('word', 'right-button' + style, 'shortcut-w',
+                               'right-button.shortcut' + style)
 
         style = self._get_optionstylename(self.option.regex)
-        self._set_option_style('regex', 'checkbox' + style, 'shortcut-r',
-                               'checkbox.shortcut' + style)
+        self._set_option_style('regex', 'right-button' + style, 'shortcut-r',
+                               'right-button.shortcut' + style)
 
     def _option_updated(self):
         self.update_option_style()
-#        self.document.style_updated()
 
+    def _show_histdlg(self, wnd, title, candidates, callback):
+        filterlist.show_listdlg(title, candidates, callback)
+
+    @command('searchdlg.history')
+    @norec
+    @norerun
+    def search_history(self, wnd):
+        def callback(result):
+            if result:
+                f, t = wnd.document.marks['searchtext']
+                wnd.document.replace(f, t, result)
+                wnd.cursor.setpos(f)
+
+        self._show_histdlg(wnd, 'Recent searches',
+                           [s for s,
+                               info in kaa.app.config.hist(
+                                   'search_text').get()],
+                           callback)
+
+    @command('searchdlg.toggle.ignorecase')
+    @norec
+    @norerun
     def toggle_option_ignorecase(self, wnd):
         self.option.ignorecase = not self.option.ignorecase
         self._option_updated()
 
+    @command('searchdlg.toggle.wordsearch')
+    @norec
+    @norerun
     def toggle_option_word(self, wnd):
         self.option.word = not self.option.word
         self._option_updated()
 
+    @command('searchdlg.toggle.regex')
+    @norec
+    @norerun
     def toggle_option_regex(self, wnd):
         self.option.regex = not self.option.regex
         self._option_updated()
@@ -306,6 +262,9 @@ class SearchDlgMode(dialogmode.DialogMode):
         if s:
             kaa.app.config.hist('search_text').add(s)
 
+    @command('searchdlg.search.next')
+    @norec
+    @norerun
     def search_next(self, wnd):
         self._save_searchstr()
         return self._search_next(wnd)
@@ -337,6 +296,9 @@ class SearchDlgMode(dialogmode.DialogMode):
 
             return ret
 
+    @command('searchdlg.search.prev')
+    @norec
+    @norerun
     def search_prev(self, wnd):
         self._save_searchstr()
         return self._search_prev(wnd)
@@ -348,8 +310,103 @@ class SearchDlgMode(dialogmode.DialogMode):
         wnd.get_label('popup').destroy()
 
 
-class ReplaceCommands(SearchCommands):
-    # todo: move commands to mode class
+replacedlg_keys = {
+    '\r': ('replacedlg.field.next'),
+    '\n': ('replacedlg.field.next'),
+    up: ('replacedlg.history'),
+}
+
+
+class ReplaceDlgMode(SearchDlgMode):
+    KEY_BINDS = [
+        keybind.cursor_keys,
+        keybind.edit_command_keys,
+        keybind.emacs_keys,
+        keybind.macro_command_keys,
+    ]
+
+    def init_keybind(self):
+        super().init_keybind()
+        self.keybind.add_keybind(replacedlg_keys)
+
+    def create_cursor(self, wnd):
+        return dialogmode.DialogCursor(wnd,
+                                       [dialogmode.MarkRange('searchtext'),
+                                        dialogmode.MarkRange('replacetext')])
+
+    def on_add_window(self, wnd):
+        super().on_add_window(wnd)
+
+    def _build_input(self, f):
+        # search text
+        f.append_text('caption', 'Search: ')
+        f.append_text('default', ' ')
+        f.append_text('default', '', mark_pair='searchtext')
+        f.append_text('default', '\n')
+
+        # replace text
+        f.append_text('caption', 'Replace:')
+        f.append_text('default', ' ')
+        f.append_text('default', '', None, mark_pair='replacetext')
+        f.append_text('default', '\n')
+
+    def _build_buttons(self, f):
+        # buttons
+        super()._build_buttons(f)
+        f.append_text('right-button', '[&All]', 'start-all', 'end-all',
+                      shortcut_style='button.shortcut', on_shortcut=self.replace_all)
+
+    def build_document(self):
+        with dialogmode.FormBuilder(self.document) as f:
+            self._build_input(f)
+            self._build_buttons(f)
+            self._build_options(f)
+
+            self.document.insert(
+                self.document.marks['searchtext'][0], self.option.text)
+
+            self.document.insert(
+                self.document.marks['replacetext'][0], self.option.replace_to)
+
+            self.update_option_style()
+
+        kaa.app.messagebar.set_message(
+            "Hit enter to move field. Hit up to show history.`")
+        return
+
+    def get_replace_str(self):
+        f, t = self.document.marks['replacetext']
+        return self.document.gettext(f, t)
+
+    def _show_replace_msg(self, wnd, on_y, on_n):
+        def cb(c):
+            wnd.activate()
+            if c == 'y':
+                on_y(wnd)
+            elif c == 'n':
+                on_n(wnd)
+            elif c == 'a':
+                self.replace_all(wnd)
+            else:
+                pass
+
+        msgdoc = msgboxmode.MsgBoxMode.show_msgbox(
+            'Replace text?', ['&Yes', '&No', '&All', '&Cancel'], cb,
+            border=True)
+
+    def _show_search_again(self, wnd, on_y, is_top):
+        def cb(c):
+            wnd.activate()
+            if c == 'r':
+                on_y(wnd)
+
+        pos = 'top' if is_top else 'bottom'
+        msgdoc = msgboxmode.MsgBoxMode.show_msgbox(
+            'Search failed. Resume from {pos} again?'.format(pos=pos),
+            ['&Resume', '&Cancel'], cb)
+
+    def _save_replstr(self):
+        kaa.app.config.hist('repl_text').add(self.get_replace_str())
 
     @command('replacedlg.field.next')
     @norec
@@ -388,107 +445,9 @@ class ReplaceCommands(SearchCommands):
         else:
             self.replace_repl_history(wnd)
 
-
-replacedlg_keys = {
-    '\r': ('replacedlg.field.next'),
-    '\n': ('replacedlg.field.next'),
-    up: ('replacedlg.history'),
-}
-
-
-class ReplaceDlgMode(SearchDlgMode):
-    KEY_BINDS = [
-        keybind.cursor_keys,
-        keybind.edit_command_keys,
-        keybind.emacs_keys,
-        keybind.macro_command_keys,
-    ]
-
-    def init_keybind(self):
-        super().init_keybind()
-        self.keybind.add_keybind(replacedlg_keys)
-
-    def init_commands(self):
-        super().init_commands()
-        self._replacecommands = ReplaceCommands()
-        self.register_command(self._replacecommands)
-
-    def create_cursor(self, wnd):
-        return dialogmode.DialogCursor(wnd,
-                                       [dialogmode.MarkRange('searchtext'),
-                                        dialogmode.MarkRange('replacetext')])
-
-    def on_add_window(self, wnd):
-        super().on_add_window(wnd)
-
-    def _build_input(self, f):
-        # search text
-        f.append_text('caption', 'Search: ')
-        f.append_text('default', ' ')
-        f.append_text('default', '', mark_pair='searchtext')
-        f.append_text('default', '\n')
-
-        # replace text
-        f.append_text('caption', 'Replace:')
-        f.append_text('default', ' ')
-        f.append_text('default', '', None, mark_pair='replacetext')
-        f.append_text('default', '\n')
-
-    def _build_buttons(self, f):
-        # buttons
-        super()._build_buttons(f)
-        f.append_text('checkbox', '[&All]', 'start-all', 'end-all',
-                      shortcut_style='button.shortcut', on_shortcut=self.replace_all)
-
-    def build_document(self):
-        with dialogmode.FormBuilder(self.document) as f:
-            self._build_input(f)
-            self._build_buttons(f)
-            self._build_options(f)
-
-            self.document.insert(
-                self.document.marks['searchtext'][0], self.option.text)
-
-            self.document.insert(
-                self.document.marks['replacetext'][0], self.option.replace_to)
-
-            self.update_option_style()
-
-        kaa.app.messagebar.set_message(
-            "Hit enter to move field. Hit up to show history.`")
-        return
-
-    def get_replace_str(self):
-        f, t = self.document.marks['replacetext']
-        return self.document.gettext(f, t)
-
-    def _show_replace_msg(self, wnd, on_y, on_n):
-        def cb(c):
-            wnd.activate()
-            if c == 'y':
-                on_y(wnd)
-            elif c == 'n':
-                on_n(wnd)
-            elif c == 'a':
-                self.replace_all(wnd)
-            else:
-                pass
-
-        msgdoc = msgboxmode.MsgBoxMode.show_msgbox(
-            'Replace text?', ['&Yes', '&No', '&All', '&Cancel'], cb)
-
-    def _show_search_again(self, wnd, on_y):
-        def cb(c):
-            wnd.activate()
-            if c == 'r':
-                on_y(wnd)
-
-        msgdoc = msgboxmode.MsgBoxMode.show_msgbox(
-            'Search failed. Resume again?', ['&Resume', '&Cancel'], cb)
-
-    def _save_replstr(self):
-        kaa.app.config.hist('repl_text').add(self.get_replace_str())
-
+    @command('searchdlg.search.next')
+    @norec
+    @norerun
     def search_next(self, wnd):
         if not self.get_search_str():
             return
@@ -504,7 +463,7 @@ class ReplaceDlgMode(SearchDlgMode):
             self._show_replace_msg(
                 wnd, self.replace_and_next, self.skip_and_next)
         else:
-            self._show_search_again(wnd, self.skip_and_next)
+            self._show_search_again(wnd, self.skip_and_next, is_top=True)
 
     _metachars = [
         (r"\\", "\\"),
@@ -537,6 +496,9 @@ class ReplaceDlgMode(SearchDlgMode):
         self._search_next(wnd)
         self.search_next(wnd)
 
+    @command('searchdlg.search.prev')
+    @norec
+    @norerun
     def search_prev(self, wnd):
         if not self.get_search_str():
             return
@@ -551,7 +513,7 @@ class ReplaceDlgMode(SearchDlgMode):
             self._show_replace_msg(
                 wnd, self.replace_and_prev, self.skip_and_prev)
         else:
-            self._show_search_again(wnd, self.skip_and_prev)
+            self._show_search_again(wnd, self.skip_and_prev, is_top=False)
 
     def replace_and_prev(self, wnd):
         self._repl_str(update_cursor=True)
